<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;

class FinalRatingAction extends Model
{
    use HasFactory;

    protected $fillable = [
        'organisation_id',
        'min_score',
        'max_score',
        'action_type',
        'action_value',
        'extra_notes',
        'merit_percent',
        'bonus_multiplier',
        'extra_notes'
    ];

    public function appraisalFinalScores()
    {
        return $this->hasMany(AppraisalFinalScore::class);
    }
}
