<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;

class RatingTypeMetric extends Model
{
    use HasFactory;

    protected $fillable = [
        'organisation_id',
        'rating_type_id',
        'rating_value',
        'metric_value',
    ];

    /**
     * The rating type this metric belongs to.
     */
    public function ratingType(): BelongsTo
    {
        return $this->belongsTo(RatingType::class);
    }
}
