<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class WeightedCriteria extends Model
{
    protected $fillable = [
        'appraisal_review_id',
        'rating_type_id',
        'goals_weight',
        'behaviors_weight',
        'competencies_weight',
        'development_weight',
        'organisation_id'
    ];
      protected $table = 'weighted_criterias';


    // relations
    public function ratingType()
    {
        return $this->belongsTo(RatingType::class);
    }
    public function appraisalReview()
    {
        return $this->belongsTo(AppraisalReview::class);
    }

}