<?php
namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class EquityAward extends Model
{
    protected $fillable = [
        'equity_plan_id',
        'employee_id',
        'appraisal_review_id',
        'grant_value',
        'shares_granted',
        'vested_shares',
        'vesting_start_date',
        'vesting_end_date',
        'status',
        'notes',
    ];

    public function plan()
    {
        return $this->belongsTo(EquityPlan::class, 'equity_plan_id');
    }

    public function employee()
    {
        return $this->belongsTo(Employee::class);
    }

    public function appraisalReview()
    {
        return $this->belongsTo(AppraisalReview::class);
    }
}
