<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasOne;

class BankInfo extends Model
{
    use HasFactory;
     protected $guarded = [ ];
    protected $table = 'bank_info';
    //Define Bank Info child relationships
    public function user() : BelongsTo {
        return $this->belongsTo(User::class);
    }
}
