<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use App\Scopes\OrganisationScope;
use Illuminate\Support\Facades\Auth;

class Commission extends Model
{
    protected $fillable = [
        'employee_id',
        'title',
        'amount',
        'created_by',
        'organisation_id',

    ];


    protected static function booted()
    {
        static::addGlobalScope(new OrganisationScope);

        // Automatically set the organisation_id before creating the model
        static::creating(function ($model) {
            if (Auth::check()) {
                $model->organisation_id = Auth::user()->organisation_id;
            }
        });
    }
    public function employee()
    {
        return $this->hasOne('App\Models\Employee', 'id', 'employee_id')->first();
    }

    public static $commissiontype = [
        'fixed' => 'Fixed',
        'percentage' => 'Percentage',
    ];
}
