<?php

namespace App\Models;

use Auth;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\Relations\HasOne;

class JobInfo extends Model
{
    use HasFactory;
    protected $guarded = [];
    // protected $with = ['allowances', 'deductions', 'department'];
    protected $table = 'job_info';
    //Define Profile child relationships
    public function user(): BelongsTo
    {
        return $this->belongsTo(User::class);
    }

    // public function department(): BelongsTo
    // {
    //     return $this->belongsTo(OrganisationDepartment::class, 'department_id');
    // }
    // public function exchange_rate(): BelongsTo
    // {
    //     return $this->belongsTo(ExchangeRate::class, 'currency','currency');
    // }
    // public function allowances(): HasMany
    // {
    //     return $this->hasMany(OrganisationEmployeeAllowance::class, 'employee_id', 'user_id');
    // }
    // public function deductions(): HasMany
    // {
    //     return $this->hasMany(EmployeeDeduction::class, 'employee_id', 'user_id');
    // }

    // public function payGrade()
    // {
    //     return $this->belongsTo(PayGrade::class, 'pay_grade_id');
    // }

    protected $cast = ['hire_date' => 'date'];
}
