<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;

class AppraisalFinalScore extends Model
{

    protected $guarded = [];
    //     protected $fillable = [
    //     'appraisal_review_id',
    //     'final_score',
    //     'action_type',
    //     'final_rating_action_id',
    //     'action_details',
    // ];


    public function finalRatingAction()
    {
        return $this->belongsTo(FinalRatingAction::class);
    }
    public function appraisalReview()
    {
        return $this->belongsTo(AppraisalReview::class);
    }

    public function appraisal_review()
    {
        return $this->belongsTo(AppraisalReview::class);
    }
}
